@@ -1,19 +1,7 @@
 /*
-    Copyright (C) 2018  Stefan Brüns <stefan.bruens@rwth-aachen.de>
+    SPDX-FileCopyrightText: 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 
@@ -21,14 +9,17 @@
 #include "kfilemetadata_debug.h"
 #include "dublincoreextractor.h"
 
-#include <QDebug>
 #include <QDomDocument>
 #include <QFile>
 #include <QXmlStreamReader>
 
+#ifdef SVG_XML_COMPRESSED_SUPPORT
+#include <KCompressionDevice>
+#endif
+
 namespace {
 
-inline QString dcNS()     { return QStringLiteral("http://purl.org/dc/elements/1.1/"); }
+//inline QString dcElementNS()     { return QStringLiteral("http://purl.org/dc/elements/1.1/"); }
 inline QString svgNS()    { return QStringLiteral("http://www.w3.org/2000/svg"); }
 inline QString rdfNS()    { return QStringLiteral("http://www.w3.org/1999/02/22-rdf-syntax-ns#"); }
 inline QString ccNS()     { return QStringLiteral("http://creativecommons.org/ns#"); }
@@ -54,6 +45,7 @@ void extractSvgText(KFileMetaData::ExtractionResult* result, const QDomElement &
 static const QStringList supportedMimeTypes = {
     QStringLiteral("application/xml"),
     QStringLiteral("image/svg+xml"),
+    QStringLiteral("image/svg+xml-compressed"),
     QStringLiteral("image/svg"),
 };
 
@@ -76,19 +68,39 @@ QStringList XmlExtractor::mimetypes() const
 void XmlExtractor::extract(ExtractionResult* result)
 {
     auto flags = result->inputFlags();
+
     QFile file(result->inputUrl());
     if (!file.open(QIODevice::ReadOnly)) {
         qCWarning(KFILEMETADATA_LOG) << "Document is not a valid file";
         return;
     }
 
+
     if ((result->inputMimetype() == QLatin1String("image/svg")) ||
+        (result->inputMimetype() == QLatin1String("image/svg+xml-compressed")) ||
         (result->inputMimetype() == QLatin1String("image/svg+xml"))) {
+
         result->addType(Type::Image);
 
+        QIODevice *ioDevice = &file;
+#ifdef SVG_XML_COMPRESSED_SUPPORT
+        std::unique_ptr<KCompressionDevice> gzReader;
+        if (result->inputMimetype() == QLatin1String("image/svg+xml-compressed")) {
+            gzReader.reset(new KCompressionDevice(&file, false, KCompressionDevice::CompressionType::GZip));
+            if (!gzReader->open(QIODevice::ReadOnly)) {
+                return;
+            }
+            ioDevice = gzReader.get();
+        }
+#else
+        if (result->inputMimetype() == QLatin1String("image/svg+xml-compressed")) {
+            return;
+        }
+#endif
+
         QDomDocument doc;
         const bool processNamespaces = true;
-        doc.setContent(&file, processNamespaces);
+        doc.setContent(ioDevice, processNamespaces);
         QDomElement svg = doc.firstChildElement();
 
         if (!svg.isNull()
@@ -102,6 +114,10 @@ void XmlExtractor::extract(ExtractionResult* result)
                 }
 
                 if (e.localName() == QLatin1String("metadata")) {
+                    if (!(flags & ExtractionResult::ExtractMetaData)) {
+                        continue;
+                    }
+
                     auto rdf = e.firstChildElement(QLatin1String("RDF"));
                     if (rdf.isNull() || rdf.namespaceURI() != rdfNS()) {
                         continue;
@@ -143,3 +159,5 @@ void XmlExtractor::extract(ExtractionResult* result)
 }
 
 } // namespace KFileMetaData
+
+#include "moc_xmlextractor.cpp"
